@@ -41,7 +41,7 @@ def get_fake_node(cluster=None, hostname=None, node_id=None, cpu_model=None,
             'mac': mac or 'd6:11:3f:b0:f1:43',
             'manufacturer': 'VirtualBox',
             'online': True,
-            'os_platform': os_platform or 'centos',
+            'os_platform': os_platform or 'ubuntu',
             'pending_addition': False,
             'pending_deletion': False,
             'pending_roles': [],
